summaryrefslogtreecommitdiffstats
path: root/backup
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2013-11-02 09:38:10 +0100
committerSven Gothel <[email protected]>2013-11-02 09:38:10 +0100
commitc5fba53a16f387ee416f19af66c6fceea7984376 (patch)
tree86a00800b53660c873daaf1806b64a0c662d403d /backup
parent529766194e3c0054a5db8436e1786db5b34aa8b9 (diff)
zfs backup: Add snapshot argument to do_zsync_increment()
Diffstat (limited to 'backup')
-rw-r--r--backup/zfs-new-snap.sh5
-rw-r--r--backup/zsync-pool2dest.sh15
2 files changed, 12 insertions, 8 deletions
diff --git a/backup/zfs-new-snap.sh b/backup/zfs-new-snap.sh
index 1a856a5..09c7e08 100644
--- a/backup/zfs-new-snap.sh
+++ b/backup/zfs-new-snap.sh
@@ -1,7 +1,8 @@
#! /bin/bash
-pool=jausoft_com
-snap=20130920
+#pool=jausoft_com
+pool=jogamp_org
+snap=20131102
zfs snapshot $pool@$snap
zfs snapshot -r $pool@$snap
diff --git a/backup/zsync-pool2dest.sh b/backup/zsync-pool2dest.sh
index a699d38..348e437 100644
--- a/backup/zsync-pool2dest.sh
+++ b/backup/zsync-pool2dest.sh
@@ -68,10 +68,10 @@ function do_zsync_initial()
}
#
# do_zsync_increment src_pool dest_pool dest_ssh
# Performs an incremental sync from 'setup_complete' up until '20130920'
#
-# Example: do_zsync_increment jogamp_org jausoft_com [email protected]
+# Example: do_zsync_increment jogamp_org jausoft_com [email protected] 20131102
#
function do_zsync_increment()
{
@@ -81,8 +81,10 @@ function do_zsync_increment()
shift
dest_ssh=$1
shift
+ snapshot=$1
+ shift
- all_zsync $src_pool $dest_pool $dest_ssh 20130920 setup_complete
+ all_zsync $src_pool $dest_pool $dest_ssh $snapshot setup_complete
echo DONE
}
@@ -91,6 +93,7 @@ function do_zsync_increment()
src_pool=jogamp_org
dest_pool=jausoft_com
+snapshot=20131102
#
#src_pool=jausoft_com
#dest_pool=jogamp_org
@@ -98,6 +101,6 @@ [email protected]
logfile=`basename $0 .sh`-"$src_pool"_2_"$dest_pool".log
-do_zsync_initial $src_pool $dest_pool $dest_ssh >& $logfile &
-#do_zsync_increment $src_pool $dest_pool $dest_ssh >& $logfile &
+#do_zsync_initial $src_pool $dest_pool $dest_ssh >& $logfile &
+do_zsync_increment $src_pool $dest_pool $dest_ssh $snapshot >& $logfile &
disown $!
@@ -68,10 +68,10 @@ function do_zsync_initial()
}
#
-# do_zsync_increment src_pool dest_pool dest_ssh
-# Performs an incremental sync from 'setup_complete' up until '20130920'
+# do_zsync_increment src_pool dest_pool dest_ssh snapshot
+# Performs an incremental sync from 'setup_complete' up until $snapshot
#